@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -56,6 +56,8 @@ public:
         QString serverUrl;
         QString password;
         QString token;
+        QString inviteToken;
+
         QByteArray userId;
         AuthenticationManager::AuthMethodType authMethodType = AuthenticationManager::AuthMethodType::Unknown;
         RuqolaServerConfig::PasswordSettings passwordSettings;
@@ -100,6 +102,7 @@ public:
     ActivitiesManager *activitiesManager() const;
 #endif
 
+    void addInvitedAccount(const AccountManagerInfo &info);
 Q_SIGNALS:
     void logoutAccountDone(const QString &accountName);
     void updateNotification(bool hasAlert, int nbUnread, const QString &accountName);
