@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "fileattachments.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "ruqola_debug.h"
 #include <QJsonArray>
 #include <QJsonObject>
 
+using namespace Qt::Literals::StringLiterals;
 FileAttachments::FileAttachments() = default;
 
 bool FileAttachments::isEmpty() const
@@ -111,6 +111,15 @@ void FileAttachments::setFileAttachments(const QList<File> &fileAttachments)
     mFileAttachments = fileAttachments;
 }
 
+void FileAttachments::addFileAttachments(const QList<File> &fileAttachments)
+{
+    for (const auto &att : fileAttachments) {
+        if (!mFileAttachments.contains(att)) {
+            mFileAttachments.append(att);
+        }
+    }
+}
+
 QDebug operator<<(QDebug d, const FileAttachments &t)
 {
     d.space() << "total" << t.total();
