@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #include "repliestest.h"
 #include "messages/replies.h"
 #include <QTest>
-QTEST_MAIN(RepliesTest)
+QTEST_GUILESS_MAIN(RepliesTest)
 
 RepliesTest::RepliesTest(QObject *parent)
     : QObject{parent}
