@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "textconvertertest.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "emoticons/emojimanager.h"
 #include "messages/message.h"
@@ -18,6 +17,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <KColorScheme>
 
 QTEST_GUILESS_MAIN(TextConverterTest)
+using namespace Qt::Literals::StringLiterals;
 
 namespace
 {
@@ -134,6 +134,12 @@ void TextConverterTest::shouldConvertText_data()
         << QStringLiteral(
                "<p><table><tr><td style='background-color:$BGCOLOR$; padding: 5px; border: 1px solid "
                "$BORDERCOLOR$'><code>&nbsp;&nbsp;first&nbsp;line<br>&nbsp;&nbsp;second&nbsp;line</code></td></tr></table></p>\n");
+
+    QTest::newRow("indented-code-block2")
+        << QStringLiteral("```\n\tfirst line\t  second line\n```")
+        << QStringLiteral(
+               "<p><table><tr><td style='background-color:#f7f7f7; padding: 5px; border: 1px solid "
+               "#707d8a'><code>&nbsp;&nbsp;&nbsp;&nbsp;first&nbsp;line&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;second&nbsp;line</code></td></tr></table></p>\n");
 }
 
 void TextConverterTest::shouldConvertText()
@@ -413,7 +419,7 @@ void TextConverterTest::shouldShowChannels_data()
         QList<Channels::ChannelInfo> channels;
         Channels::ChannelInfo info;
         info.name = QStringLiteral("foo");
-        info.identifier = QByteArrayLiteral("idd");
+        info.identifier = "idd"_ba;
         channels.append(info);
         QTest::newRow("word#") << QStringLiteral("#foo") << QStringLiteral("<p><a href='ruqola:/room/idd'>#foo</a></p>\n") << mentions << channels;
     }
@@ -422,7 +428,7 @@ void TextConverterTest::shouldShowChannels_data()
         QList<Channels::ChannelInfo> channels;
         Channels::ChannelInfo info;
         info.name = QStringLiteral("bla");
-        info.identifier = QByteArrayLiteral("idd");
+        info.identifier = "idd"_ba;
         channels.append(info);
         QTest::newRow("not existing room") << QStringLiteral("#foo") << QStringLiteral("<p><a href='ruqola:/room/foo'>#foo</a></p>\n") << mentions << channels;
     }
@@ -432,7 +438,7 @@ void TextConverterTest::shouldShowChannels_data()
         Channels::ChannelInfo info;
         info.name = QStringLiteral("bla");
         info.fname = QStringLiteral("FNAME");
-        info.identifier = QByteArrayLiteral("idd");
+        info.identifier = "idd"_ba;
         channels.append(info);
         QTest::newRow("use fname") << QStringLiteral("#bla") << QStringLiteral("<p><a href='ruqola:/room/idd'>#FNAME</a></p>\n") << mentions << channels;
     }
@@ -443,13 +449,13 @@ void TextConverterTest::shouldShowChannels_data()
         {
             Channels::ChannelInfo info;
             info.name = QStringLiteral("bli");
-            info.identifier = QByteArrayLiteral("112");
+            info.identifier = "112"_ba;
             channels.append(info);
         }
         {
             Channels::ChannelInfo info;
             info.name = QStringLiteral("oss");
-            info.identifier = QByteArrayLiteral("kli");
+            info.identifier = "kli"_ba;
             channels.append(info);
         }
         QTest::newRow("multi channel") << QStringLiteral("foo #bli blass #oss")
@@ -510,11 +516,11 @@ void TextConverterTest::shouldShowUsers_data()
     }
     {
         QMap<QString, QByteArray> mentions;
-        mentions.insert(QStringLiteral("kde"), QByteArrayLiteral("bb"));
+        mentions.insert(QStringLiteral("kde"), "bb"_ba);
         QList<Channels::ChannelInfo> lst;
         Channels::ChannelInfo info;
         info.name = QStringLiteral("foo");
-        info.identifier = QByteArrayLiteral("idd");
+        info.identifier = "idd"_ba;
         lst.append(info);
         QTest::newRow("channel-user1") << QStringLiteral("#foo @kde")
                                        << QStringLiteral("<p><a href='ruqola:/room/idd'>#foo</a> <a href='ruqola:/user/bb'>@kde</a></p>\n") << mentions << lst;
@@ -522,16 +528,44 @@ void TextConverterTest::shouldShowUsers_data()
 
     {
         QMap<QString, QByteArray> mentions;
-        mentions.insert(QStringLiteral("kde1"), QByteArrayLiteral("bb"));
+        mentions.insert(QStringLiteral("kde1"), "bb"_ba);
         QList<Channels::ChannelInfo> lst;
         Channels::ChannelInfo info;
         info.name = QStringLiteral("foo2");
-        info.identifier = QByteArrayLiteral("idd");
+        info.identifier = "idd"_ba;
         lst.append(info);
         QTest::newRow("channel-user-unknown") << QStringLiteral("#foo @kde")
                                               << QStringLiteral("<p><a href='ruqola:/room/foo'>#foo</a> <a href='ruqola:/user/kde'>@kde</a></p>\n") << mentions
                                               << lst;
     }
+
+    {
+        QMap<QString, QByteArray> mentions;
+        mentions.insert(QStringLiteral("nico"), "bb"_ba);
+        mentions.insert(QStringLiteral("nico.bla"), "bb_new"_ba);
+        QList<Channels::ChannelInfo> lst;
+        QTest::newRow("quasi same name") << QStringLiteral("@nico foo @nico.bla")
+                                         << QStringLiteral("<p><a href='ruqola:/user/bb'>@nico</a> foo <a href='ruqola:/user/bb_new'>@nico.bla</a></p>\n")
+                                         << mentions << lst;
+    }
+
+    {
+        QMap<QString, QByteArray> mentions;
+        mentions.insert(QStringLiteral("nico"), "bb"_ba);
+        mentions.insert(QStringLiteral("nico.bla"), "bb_new"_ba);
+        QList<Channels::ChannelInfo> lst;
+        QTest::newRow("quasi same name-2") << QStringLiteral("foo @nico.bla") << QStringLiteral("<p>foo <a href='ruqola:/user/bb_new'>@nico.bla</a></p>\n")
+                                           << mentions << lst;
+    }
+
+    {
+        QMap<QString, QByteArray> mentions;
+        mentions.insert(QStringLiteral("nico"), "bb"_ba);
+        mentions.insert(QStringLiteral("nico.bla"), "bb_new"_ba);
+        QList<Channels::ChannelInfo> lst;
+        QTest::newRow("quasi same name-1") << QStringLiteral("@nico foo") << QStringLiteral("<p><a href='ruqola:/user/bb'>@nico</a> foo</p>\n") << mentions
+                                           << lst;
+    }
 }
 
 void TextConverterTest::shouldShowSearchedText_data()
