@@ -7,6 +7,7 @@
 #pragma once
 
 #include "libruqolacore_export.h"
+#include "misc/methodcalljob.h"
 #include "model/threadmessagemodel.h"
 #include <QCache>
 #include <QMap>
@@ -36,15 +37,21 @@ Q_SIGNALS:
 
 protected:
     virtual bool startJob(RocketChatRestApi::RestApiAbstractJob *job); // virtual for unittest
+    virtual RocketChatRestApi::MethodCallJob::MethodCallJobInfo generateMethodCallInfo(const QByteArray &messageId); // virtual for unittest
 
 private:
     LIBRUQOLACORE_NO_EXPORT void slotGetThreadMessagesDone(const QJsonObject &obj, const QByteArray &threadMessageId);
     LIBRUQOLACORE_NO_EXPORT void slotGetMessageDone(const QJsonObject &obj, const QByteArray &messageId);
+    LIBRUQOLACORE_NO_EXPORT void slotGetSingleMessageDone(const QJsonObject &obj, const QByteArray &messageId);
 
     mutable QMap<QByteArray, RocketChatRestApi::GetThreadMessagesJob *> mThreadMessageJobs;
     QCache<QByteArray, ThreadMessageModel> mThreadMessageModels;
 
+#ifdef USE_GET_MESSAGE_JOB
     mutable QMap<QByteArray, RocketChatRestApi::GetMessageJob *> mMessageJobs;
+#else
+    mutable QMap<QByteArray, RocketChatRestApi::MethodCallJob *> mMessageJobs;
+#endif
     QCache<QByteArray, Message> mMessages;
     RocketChatAccount *const mRocketChatAccount;
 };
