@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "teamroomcompletermodel.h"
-#include "utils.h"
 #include <QModelIndex>
 
 TeamRoomCompleterModel::TeamRoomCompleterModel(QObject *parent)
@@ -36,7 +35,8 @@ void TeamRoomCompleterModel::setRooms(const QList<TeamRoomCompleter> &teams)
 
 int TeamRoomCompleterModel::rowCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent)
+    if (parent.isValid()) // flat model
+        return 0;
     return mRooms.count();
 }
 
