@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "moderationreporteduserinfos.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "ruqola_debug.h"
 
 #include <QJsonArray>
 #include <QJsonObject>
 
+using namespace Qt::Literals::StringLiterals;
 ModerationReportedUserInfos::ModerationReportedUserInfos() = default;
 
 QDebug operator<<(QDebug d, const ModerationReportedUserInfos &t)
@@ -20,7 +20,7 @@ QDebug operator<<(QDebug d, const ModerationReportedUserInfos &t)
     d.space() << "offset" << t.offset();
     d.space() << "ModerationReportedUserInfosCount" << t.moderationReportedUserInfosCount() << "\n";
     for (int i = 0, total = t.ModerationReportedUserInfosList().count(); i < total; ++i) {
-        d << t.ModerationReportedUserInfosList().at(i) << "\n";
+        d.space() << t.ModerationReportedUserInfosList().at(i) << "\n";
     }
     return d;
 }
