@@ -1,7 +1,7 @@
 /*
 
  * SPDX-FileCopyrightText: 2016 Riccardo Iaconelli <riccardo@kde.org>
- * SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  *
@@ -33,149 +33,12 @@
 #include <QJsonArray>
 using namespace Qt::Literals::StringLiterals;
 
-void process_updatePublicsettings(const QJsonObject &obj, RocketChatAccount *account)
-{
-    // qDebug() << " obj " << obj;
-    // Update it.
-    account->parsePublicSettings(obj, true);
-
-    // qCDebug(RUQOLA_LOG) << " configs"<<configs;
-    if (account->ruqolaLogger()) {
-        account->ruqolaLogger()->dataReceived(QByteArrayLiteral("Update Public Settings:") + QJsonDocument(obj).toJson());
-    }
-}
-
-void process_publicsettings(const QJsonObject &obj, RocketChatAccount *account)
-{
-    // qDebug() << " obj " << obj;
-    account->parsePublicSettings(obj, false);
-
-    // qCDebug(RUQOLA_LOG) << " configs"<<configs;
-    if (account->ruqolaLogger()) {
-        account->ruqolaLogger()->dataReceived(QByteArrayLiteral("Public Settings:") + QJsonDocument(obj).toJson());
-    }
-}
-
-void process_publicsettings_administrator(const QJsonObject &obj, RocketChatAccount *account)
-{
-    Q_EMIT account->publicSettingLoaded(obj);
-
-    // qCDebug(RUQOLA_LOG) << " configs"<<configs;
-    if (account->ruqolaLogger()) {
-        account->ruqolaLogger()->dataReceived(QByteArrayLiteral("Administrator Public Settings:") + QJsonDocument(obj).toJson());
-    }
-}
-
-void process_privatesettings_administrator(const QJsonObject &obj, RocketChatAccount *account)
-{
-    Q_EMIT account->privateSettingLoaded(obj);
-
-    // qCDebug(RUQOLA_LOG) << " configs"<<configs;
-    if (account->ruqolaLogger()) {
-        account->ruqolaLogger()->dataReceived(QByteArrayLiteral("Administrator Private Settings:") + QJsonDocument(obj).toJson());
-    }
-}
-
-void process_permissions_administrator(const QJsonObject &obj, RocketChatAccount *account)
-{
-    Q_EMIT account->permissionSettingLoaded(obj);
-
-    // qCDebug(RUQOLA_LOG) << " configs"<<configs;
-    if (account->ruqolaLogger()) {
-        account->ruqolaLogger()->dataReceived(QByteArrayLiteral("Administrator Permissions:") + QJsonDocument(obj).toJson());
-    }
-}
-
-void rooms_parsing(const QJsonObject &root, RocketChatAccount *account)
-{
-    const QJsonObject obj = root.value("result"_L1).toObject();
-    RoomModel *model = account->roomModel();
-
-    // qDebug() << " doc " << doc;
-
-    // QJsonArray removed = obj.value("remove"_L1).toArray();
-    // qDebug() << " rooms_parsing: room removed *************************************************" << removed;
-    const QJsonArray updated = obj.value("update"_L1).toArray();
-    // qDebug() << " rooms_parsing: updated  *******************************************************: "<< updated;
-
-    for (int i = 0; i < updated.size(); i++) {
-        QJsonObject roomJson = updated.at(i).toObject();
-        const QString roomType = roomJson.value("t"_L1).toString();
-        if (account->ruqolaLogger()) {
-            QJsonDocument d;
-            d.setObject(roomJson);
-
-            account->ruqolaLogger()->dataReceived(QByteArrayLiteral("Rooms:") + d.toJson());
-        }
-        // TODO: why checking the room type?
-        if (roomType == QLatin1Char('c') // Chat
-            || roomType == QLatin1Char('p') /*Private chat*/
-            || roomType == QLatin1Char('d') /*Direct chat*/) {
-            // let's be extra safe around crashes
-            if (account->loginStatus() == AuthenticationManager::LoggedIn) {
-                model->updateRoom(roomJson);
-            }
-        }
-    }
-}
-
-void getsubscription_parsing(const QJsonObject &root, RocketChatAccount *account)
-{
-    // qCDebug(RUQOLA_MESSAGE_LOG) << " getsubscription_parsing " << root;
-    const QJsonObject obj = root.value("result"_L1).toObject();
-    RoomModel *model = account->roomModel();
-
-    // qDebug() << " doc " << doc;
-
-    const QJsonArray removed = obj.value("remove"_L1).toArray();
-    if (!removed.isEmpty()) {
-        // TODO implement it.
-        qDebug() << " room removed " << removed;
-    }
-
-    const QJsonArray updated = obj.value("update"_L1).toArray();
-    // qDebug() << " updated : "<< updated;
-
-    for (int i = 0; i < updated.size(); i++) {
-        QJsonObject room = updated.at(i).toObject();
-
-        const QString roomType = room.value("t"_L1).toString();
-        if (account->ruqolaLogger()) {
-            QJsonDocument d;
-            d.setObject(room);
-
-            account->ruqolaLogger()->dataReceived(QByteArrayLiteral("Rooms subscriptions:") + d.toJson());
-        }
-        if (roomType == QLatin1Char('c') // Chat
-            || roomType == QLatin1Char('p') // Private chat
-            || roomType == QLatin1Char('d')) { // Direct chat
-            // let's be extra safe around crashes
-            if (account->loginStatus() == AuthenticationManager::LoggedIn) {
-                model->addRoom(room);
-            }
-        } else if (roomType == QLatin1Char('l')) { // Live chat
-            qCDebug(RUQOLA_LOG) << "Live Chat not implemented yet";
-        }
-    }
-    // We need to load all room after get subscription to update parameters
-    QJsonObject params;
-    // TODO use timeStamp too
-    params["$date"_L1] = QJsonValue(0); // get ALL rooms we've ever seen
-    // Add timestamp https://developer.rocket.chat/reference/api/realtime-api/method-calls/get-rooms
-    account->ddp()->method(QStringLiteral("rooms/get"), params, rooms_parsing);
-
-    account->initializeAccount();
-}
-
 RocketChatBackend::RocketChatBackend(RocketChatAccount *account, QObject *parent)
     : QObject(parent)
     , mRocketChatAccount(account)
 {
     connect(mRocketChatAccount, &RocketChatAccount::loginStatusChanged, this, &RocketChatBackend::slotLoginStatusChanged);
     connect(mRocketChatAccount, &RocketChatAccount::userIdChanged, this, &RocketChatBackend::subscribeRegistration);
-    connect(mRocketChatAccount, &RocketChatAccount::changed, this, &RocketChatBackend::slotChanged);
-    connect(mRocketChatAccount, &RocketChatAccount::added, this, &RocketChatBackend::slotAdded);
-    connect(mRocketChatAccount, &RocketChatAccount::removed, this, &RocketChatBackend::slotRemoved);
     connect(mRocketChatAccount, &RocketChatAccount::ddpConnectedChanged, this, &RocketChatBackend::slotDDPConnectedChanged);
     connect(mRocketChatAccount, &RocketChatAccount::passwordAvailable, this, &RocketChatBackend::tryAutoLogin);
 }
@@ -205,69 +68,6 @@ void RocketChatBackend::slotDDPConnectedChanged(bool connected)
     }
 }
 
-void RocketChatBackend::loadPublicSettings(qint64 timeStamp)
-{
-    auto ddp = mRocketChatAccount->ddp();
-    // https://developer.rocket.chat/reference/api/realtime-api/method-calls/get-public-settings
-    QJsonObject params;
-    if (timeStamp != -1) {
-        // "params": [ { "$date": 1480377601 } ]
-        params["$date"_L1] = timeStamp;
-        qDebug() << "RocketChatBackend::loadPublicSettings load from: " << params;
-        ddp->method(QStringLiteral("public-settings/get"), params, process_updatePublicsettings);
-    } else {
-        ddp->method(QStringLiteral("public-settings/get"), params, process_publicsettings);
-    }
-}
-
-void RocketChatBackend::loadPermissionsAdministrator(qint64 timeStamp)
-{
-    auto ddp = mRocketChatAccount->ddp();
-    if (!ddp->isConnected()) {
-        return;
-    }
-    // https://developer.rocket.chat/docs/get-permissions
-    QJsonObject params;
-    if (timeStamp != -1) {
-        // "params": [ { "$date": 1480377601 } ]
-        params["$date"_L1] = timeStamp;
-    }
-    qDebug() << " params " << params;
-    ddp->method(QStringLiteral("permissions/get"), params, process_permissions_administrator);
-}
-
-void RocketChatBackend::loadPrivateSettingsAdministrator(qint64 timeStamp)
-{
-    auto ddp = mRocketChatAccount->ddp();
-    if (!ddp->isConnected()) {
-        return;
-    }
-    // https://developer.rocket.chat/docs/get-permissions
-    QJsonObject params;
-    if (timeStamp != -1) {
-        // "params": [ { "$date": 1480377601 } ]
-        params["$date"_L1] = timeStamp;
-    }
-    qDebug() << " params " << params;
-    ddp->method(QStringLiteral("private-settings/get"), params, process_privatesettings_administrator);
-}
-
-void RocketChatBackend::loadPublicSettingsAdministrator(qint64 timeStamp)
-{
-    auto ddp = mRocketChatAccount->ddp();
-    if (!ddp->isConnected()) {
-        return;
-    }
-    // https://developer.rocket.chat/reference/api/realtime-api/method-calls/get-public-settings
-    QJsonObject params;
-    if (timeStamp != -1) {
-        // "params": [ { "$date": 1480377601 } ]
-        params["$date"_L1] = timeStamp;
-    }
-    qDebug() << " params " << params;
-    ddp->method(QStringLiteral("public-settings/get"), params, process_publicsettings_administrator);
-}
-
 void RocketChatBackend::updateVideoConferenceInfo(const Message &m)
 {
     // Update video conf info
@@ -338,7 +138,7 @@ void RocketChatBackend::processIncomingMessages(const QJsonArray &messages, bool
         if (mRocketChatAccount->ruqolaLogger()) {
             QJsonDocument d;
             d.setObject(o);
-            mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("Message:") + d.toJson());
+            mRocketChatAccount->ruqolaLogger()->dataReceived("Message:"_ba + d.toJson());
         } else {
             qCDebug(RUQOLA_MESSAGE_LOG) << " new message: " << o;
         }
@@ -381,7 +181,7 @@ void RocketChatBackend::ddpLogin()
     // if (ddp->authenticationManager()->loginPassword(mRocketChatAccount->settings()->userName(), mRocketChatAccount->settings()->password())) {
     if (ddp->authenticationManager()->login()) {
         qCDebug(RUQOLA_AUTHENTICATION_LOG) << "ddpLogin: login ok" << mRocketChatAccount->accountName() << mRocketChatAccount->userName();
-        initializeSubscription(ddp);
+        ddp->initializeSubscription();
     } else {
         qCWarning(RUQOLA_AUTHENTICATION_LOG) << "ddpLogin: could not reconnect" << mRocketChatAccount->accountName() << mRocketChatAccount->userName();
     }
@@ -412,7 +212,7 @@ void RocketChatBackend::slotLoginStatusChanged()
             connect(restApi, &Connection::getOwnInfoDone, mRocketChatAccount, &RocketChatAccount::parseOwnInfoDone, Qt::UniqueConnection);
 
             auto ddp = mRocketChatAccount->ddp();
-            initializeSubscription(ddp);
+            ddp->initializeSubscription();
         }
         restApi->listAllPermissions();
         restApi->getPrivateSettings();
@@ -420,19 +220,6 @@ void RocketChatBackend::slotLoginStatusChanged()
     }
 }
 
-void RocketChatBackend::initializeSubscription(DDPClient *ddp)
-{
-    QJsonObject params;
-    // TODO use timeStamp too
-    params["$date"_L1] = QJsonValue(0); // get ALL rooms we've ever seen
-
-    std::function<void(QJsonObject, RocketChatAccount *)> subscription_callback = [=](const QJsonObject &obj, RocketChatAccount *account) {
-        getsubscription_parsing(obj, account);
-    };
-
-    ddp->method(QStringLiteral("subscriptions/get"), params, subscription_callback);
-}
-
 void RocketChatBackend::slotPrivateInfoDone(const QJsonObject &data)
 {
     qDebug() << "parse private info not implemented . Needed ? "; // << data;
@@ -448,22 +235,22 @@ void RocketChatBackend::parseServerVersionDone(const QString &version)
 void RocketChatBackend::tryAutoLogin()
 {
     qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin for account" << mRocketChatAccount->accountName();
-    if (mRocketChatAccount->serverVersion().isEmpty()) {
+    if (mRocketChatAccount->ruqolaServerConfig()->serverVersion().isEmpty()) {
         qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin: can't autologin yet, waiting for parseServerVersionDone";
         return;
     }
-    if (mRocketChatAccount->authMethodType() == AuthenticationManager::AuthMethodType::Password) {
-        if (mRocketChatAccount->password().isEmpty()) {
+    if (mRocketChatAccount->settings()->authMethodType() == AuthenticationManager::AuthMethodType::Password) {
+        if (mRocketChatAccount->settings()->password().isEmpty()) {
             qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin: can't autologin (yet?), no password set";
             return;
         }
-    } else if (mRocketChatAccount->authMethodType() == AuthenticationManager::AuthMethodType::PersonalAccessToken) {
-        if (mRocketChatAccount->authToken().isEmpty()) {
+    } else if (mRocketChatAccount->settings()->authMethodType() == AuthenticationManager::AuthMethodType::PersonalAccessToken) {
+        if (mRocketChatAccount->settings()->authToken().isEmpty()) {
             qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin: can't autologin (yet?), no authToken";
             return;
         }
     } else {
-        qCWarning(RUQOLA_RECONNECT_LOG) << " tryAutoLogin: check not implemented for " << mRocketChatAccount->authMethodType();
+        qCWarning(RUQOLA_RECONNECT_LOG) << " tryAutoLogin: check not implemented for " << mRocketChatAccount->settings()->authMethodType();
     }
     if (Ruqola::useRestApiLogin()) {
         qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin: try login REST API" << mRocketChatAccount->accountName();
@@ -483,7 +270,7 @@ void RocketChatBackend::slotRemoved(const QJsonObject &object)
         if (mRocketChatAccount->ruqolaLogger()) {
             QJsonDocument d;
             d.setObject(object);
-            mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("users: Removed user:") + d.toJson());
+            mRocketChatAccount->ruqolaLogger()->dataReceived("users: Removed user:"_ba + d.toJson());
         } else {
             qDebug() << "USER REMOVED VALUE" << object;
         }
@@ -511,10 +298,11 @@ void RocketChatBackend::slotAdded(const QJsonObject &object)
             // TODO add current user ? me ?
             User user;
             user.parseUser(object);
+            qDebug() << " SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS" << object;
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("users: Add User:") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("users: Add User:"_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_LOG) << "USER ADDED VALUE" << object;
             }
@@ -536,7 +324,7 @@ void RocketChatBackend::slotAdded(const QJsonObject &object)
         if (mRocketChatAccount->ruqolaLogger()) {
             QJsonDocument d;
             d.setObject(object);
-            mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("autocompleteRecords: Add User:") + d.toJson());
+            mRocketChatAccount->ruqolaLogger()->dataReceived("autocompleteRecords: Add User:"_ba + d.toJson());
         } else {
             qCDebug(RUQOLA_LOG) << "AutoCompleteRecords VALUE" << object;
         }
@@ -546,7 +334,7 @@ void RocketChatBackend::slotAdded(const QJsonObject &object)
         if (mRocketChatAccount->ruqolaLogger()) {
             QJsonDocument d;
             d.setObject(object);
-            mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("room_files: Add Files:") + d.toJson());
+            mRocketChatAccount->ruqolaLogger()->dataReceived("room_files: Add Files:"_ba + d.toJson());
         } else {
             qCDebug(RUQOLA_LOG) << "room_files VALUE" << object;
         }
@@ -576,7 +364,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
         if (mRocketChatAccount->ruqolaLogger()) {
             QJsonDocument d;
             d.setObject(object);
-            mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("users: User Changed:") + d.toJson());
+            mRocketChatAccount->ruqolaLogger()->dataReceived("users: User Changed:"_ba + d.toJson());
         } else {
             qCDebug(RUQOLA_LOG) << "USER CHANGED" << object;
         }
@@ -584,7 +372,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
         if (mRocketChatAccount->ruqolaLogger()) {
             QJsonDocument d;
             d.setObject(object);
-            mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("rooms: Room Changed:") + d.toJson());
+            mRocketChatAccount->ruqolaLogger()->dataReceived("rooms: Room Changed:"_ba + d.toJson());
         } else {
             qCDebug(RUQOLA_LOG) << "ROOMS CHANGED: " << object;
         }
@@ -593,13 +381,26 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
         qCDebug(RUQOLA_LOG) << " EVENT " << eventname << "account name: " << mRocketChatAccount->accountName() << " contents " << contents
                             << fields.value("args"_L1).toArray().toVariantList();
 
-        if (eventname.endsWith("/subscriptions-changed"_L1)) {
+        if (eventname.endsWith("/uiInteraction"_L1)) {
+            if (mRocketChatAccount->ruqolaLogger()) {
+                QJsonDocument d;
+                d.setObject(fields);
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-user: uiInteraction:"_ba + d.toJson());
+            } else {
+                qCDebug(RUQOLA_LOG) << "stream-notify-user: uiInteraction " << object;
+            }
+            // TODO implement it
+            qDebug() << "uiInteraction********* " << contents;
+            if (mRocketChatAccount) {
+                Q_EMIT mRocketChatAccount->showUiInteraction(contents);
+            }
+        } else if (eventname.endsWith("/subscriptions-changed"_L1)) {
             RoomModel *model = mRocketChatAccount->roomModel();
             model->updateSubscription(contents);
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(fields);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-user: subscriptions-changed:") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-user: subscriptions-changed:"_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_LOG) << "stream-notify-user: subscriptions-changed " << object;
             }
@@ -628,13 +429,13 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-user: Room Changed:") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-user: Room Changed:"_ba + d.toJson());
             }
         } else if (eventname.endsWith("/notification"_L1)) {
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-user: notification:") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-user: notification:"_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << "NOTIFICATION: " << object;
             }
@@ -643,7 +444,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-user: webrtc: ") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-user: webrtc: "_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_LOG) << "WEBRTC CHANGED: " << object;
             }
@@ -652,7 +453,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-user: otr: ") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-user: otr: "_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_LOG) << "OTR CHANGED: " << object;
             }
@@ -662,7 +463,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-user: message: ") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-user: message: "_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_LOG) << "stream-notify-user : Message: " << object;
             }
@@ -674,7 +475,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-user: userData event: ") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-user: userData event: "_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_LOG) << "stream-notify-user: userData event: " << object;
             }
@@ -687,7 +488,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-user: video-conference ") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-user: video-conference "_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_LOG) << "stream-notify-user: video-conference :account name:" << mRocketChatAccount->accountName() << "object" << object;
             }
@@ -696,13 +497,13 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
         } else if (eventname.endsWith("/force_logout"_L1)) {
             qCDebug(RUQOLA_LOG) << " FORCE LOGOUT!!!!";
             // Clear auth token otherwise we can't reconnect.
-            mRocketChatAccount->setAuthToken({});
+            mRocketChatAccount->settings()->setAuthToken({});
             qCDebug(RUQOLA_LOG) << "stream-notify-user : message event " << eventname << " contents " << contents;
         } else {
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-user: Unknown event: ") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-user: Unknown event: "_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << "Unknown change: " << object;
             }
@@ -718,7 +519,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-room: DeleteMessage:") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-room: DeleteMessage:"_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_LOG) << "Delete message" << object;
             }
@@ -744,7 +545,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-room: typing:") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-room: typing:"_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_LOG) << "typing message" << object;
             }
@@ -755,26 +556,14 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             qCWarning(RUQOLA_LOG) << "stream-notify-room: typing event ? " << eventname << " content  " << contents.toVariantList() << " object " << object;
             const QString typingUserName = contents.toVariantList().at(0).toString();
             if (typingUserName != mRocketChatAccount->settings()->userName()) {
-                const QString val = contents.toVariantList().at(1).toString();
-                // qDebug() << " val ************ " << val << " contents.toVariantList().at(1 " << contents.toVariantList().at(1);
-                bool status = false;
-                if (contents.toVariantList().at(1).toBool()) {
-                    // qDebug() << " TYPING *************************************************";
-                    status = true;
-                } else if (!contents.toVariantList().at(1).toList().isEmpty()) {
-                    if (contents.toVariantList().at(1).toList().at(0).toString() == "user-typing"_L1) {
-                        // qDebug() << " FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF typing user";
-                        status = true;
-                    }
-                }
-                // qDebug() << " typing : object " << object << " status " << status;
+                const bool status = Utils::userActivity(contents);
                 mRocketChatAccount->receiveTypingNotificationManager()->insertTypingNotification(roomId.toLatin1(), typingUserName, status);
             }
         } else if (eventname.endsWith("/deleteMessageBulk"_L1)) {
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("deleteMessageBulk: DeleteMessage:") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("deleteMessageBulk: DeleteMessage:"_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_LOG) << "Delete message" << object;
             }
@@ -787,7 +576,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             if (mRocketChatAccount->ruqolaLogger()) {
                 QJsonDocument d;
                 d.setObject(object);
-                mRocketChatAccount->ruqolaLogger()->dataReceived(QByteArrayLiteral("stream-notify-room:  Unknown event ?") + d.toJson());
+                mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-room:  Unknown event ?"_ba + d.toJson());
             } else {
                 qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << "stream-notify-room:  Unknown event ? " << eventname;
             }
@@ -795,6 +584,13 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
     } else if (collection == "stream-notify-logged"_L1) {
         const QString eventname = fields.value("eventName"_L1).toString();
         qCDebug(RUQOLA_LOG) << " EVENT " << eventname << " contents " << contents << fields.value("args"_L1).toArray().toVariantList();
+        if (mRocketChatAccount->ruqolaLogger()) {
+            QJsonDocument d;
+            d.setObject(object);
+            mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-logged: "_ba + d.toJson());
+        } else {
+            qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << "stream-notify-logged: " << eventname;
+        }
         if (eventname == "roles-change"_L1) {
             mRocketChatAccount->rolesChanged(contents);
         } else if (eventname == "updateAvatar"_L1) {
@@ -822,6 +618,14 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
         }
     } else if (collection == "stream-notify-all"_L1) {
         const QString eventname = fields.value("eventName"_L1).toString();
+        if (mRocketChatAccount->ruqolaLogger()) {
+            QJsonDocument d;
+            d.setObject(object);
+            mRocketChatAccount->ruqolaLogger()->dataReceived("stream-notify-all: "_ba + d.toJson());
+        } else {
+            qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << "stream-notify-all: " << eventname;
+        }
+
         if (eventname == "deleteCustomSound"_L1) {
             mRocketChatAccount->deleteCustomSound(contents);
         } else if (eventname == "updateCustomSound"_L1) {
@@ -832,11 +636,37 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
         //{"collection":"stream-notify-all","fields":{"args":[{"soundData":{"_id":"LmShBQiqaCJDbgduR","_updatedAt":{"$date":1603350386481},"extension":"mp3","name":"ss"}}],"eventName":"deleteCustomSound"},"id":"id","msg":"changed"}
     } else if (collection == "stream-stdout"_L1) {
         mRocketChatAccount->addStdoutInfo(contents);
+        if (mRocketChatAccount->ruqolaLogger()) {
+            QJsonDocument d;
+            d.setObject(object);
+            mRocketChatAccount->ruqolaLogger()->dataReceived("stream-stdout: "_ba + d.toJson());
+        } else {
+            qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << "stream-stdout: " << contents;
+        }
     } else if (collection == "stream-roles"_L1) {
         const QString eventname = fields.value("eventName"_L1).toString();
+        if (mRocketChatAccount->ruqolaLogger()) {
+            QJsonDocument d;
+            d.setObject(object);
+            mRocketChatAccount->ruqolaLogger()->dataReceived("stream-roles: "_ba + d.toJson());
+        } else {
+            qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << "stream-roles: " << contents;
+        }
         if (eventname == "roles"_L1) {
             mRocketChatAccount->updateRoles(contents);
         }
+    } else if (collection == "stream-apps"_L1) {
+        const QString eventname = fields.value("eventName"_L1).toString();
+        if (mRocketChatAccount->ruqolaLogger()) {
+            QJsonDocument d;
+            d.setObject(object);
+            mRocketChatAccount->ruqolaLogger()->dataReceived("stream-apps: "_ba + d.toJson());
+        } else {
+            qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << "stream-apps: " << eventname;
+        }
+        if (eventname == "apps"_L1) {
+            mRocketChatAccount->updateApps(contents);
+        }
     } else {
         qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << " Other collection type changed " << collection << " object " << object;
     }
@@ -845,7 +675,6 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
 void RocketChatBackend::subscribeRegistration()
 {
     qCDebug(RUQOLA_LOG) << "subscribe registration";
-    // TODO verify if we don"t send two subscription.
     const QString userId{QString::fromLatin1(mRocketChatAccount->settings()->userId())};
     const QStringList listStreamNotifierUser{
         QStringLiteral("notification"),
@@ -858,6 +687,7 @@ void RocketChatBackend::subscribeRegistration()
         QStringLiteral("userData"),
         QStringLiteral("banners"),
         QStringLiteral("force_logout"),
+        QStringLiteral("uiInteraction"),
     };
     for (const QString &str : listStreamNotifierUser) {
         QJsonArray params;
@@ -909,6 +739,11 @@ void RocketChatBackend::subscribeRegistration()
         const QJsonArray params{QJsonValue(QStringLiteral("roles"))};
         mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-roles"), params);
     }
+
+    {
+        const QJsonArray params{QJsonValue(QStringLiteral("apps"))};
+        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-apps"), params);
+    }
 }
 
 #include "moc_rocketchatbackend.cpp"
