@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -108,9 +108,9 @@ bool TeamInfo::hasTeamRoom() const
 
 QDebug operator<<(QDebug d, const TeamInfo &t)
 {
-    d << "team id: " << t.teamId();
-    d << "is Main Team: " << t.mainTeam();
-    d << "autojoin: " << t.autoJoin();
-    d << "roomCount: " << t.roomsCount();
+    d.space() << "team id:" << t.teamId();
+    d.space() << "is Main Team:" << t.mainTeam();
+    d.space() << "autojoin:" << t.autoJoin();
+    d.space() << "roomCount:" << t.roomsCount();
     return d;
 }
