@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,7 +19,6 @@ public:
 
     [[nodiscard]] bool start() override;
     [[nodiscard]] bool requireHttpAuthentication() const override;
-    [[nodiscard]] bool canStart() const override;
     [[nodiscard]] QNetworkRequest request() const override;
 
     [[nodiscard]] QJsonDocument json() const;
@@ -29,8 +28,5 @@ Q_SIGNALS:
 
 protected:
     LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
-
-private:
-    void slotEnabledEmail();
 };
 }
