@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -27,7 +27,7 @@ void GetMessageJobTest::shouldGenerateRequest()
 {
     GetMessageJob job;
     QNetworkRequest request = QNetworkRequest(QUrl());
-    job.setMessageId(QByteArrayLiteral("foo"));
+    job.setMessageId("foo"_ba);
     verifyAuthentication(&job, request);
     QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/chat.getMessage?msgId=foo")));
 }
