@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -44,8 +44,8 @@ void GetPersonalAccessTokensJobTest::shouldGenerateRequest()
         job.setRestApiMethod(&method);
         const QNetworkRequest request = job.request();
         QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/users.getPersonalAccessTokens")));
-        QCOMPARE(request.rawHeader(QByteArrayLiteral("X-Auth-Token")), authToken.toLocal8Bit());
-        QCOMPARE(request.rawHeader(QByteArrayLiteral("X-User-Id")), userId.toLocal8Bit());
+        QCOMPARE(request.rawHeader("X-Auth-Token"_ba), authToken.toLocal8Bit());
+        QCOMPARE(request.rawHeader("X-User-Id"_ba), userId.toLocal8Bit());
     }
 }
 
