@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "loademojicustomjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
@@ -13,6 +12,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QJsonObject>
 #include <QUrlQuery>
 using namespace RocketChatRestApi;
+using namespace Qt::Literals::StringLiterals;
 LoadEmojiCustomJob::LoadEmojiCustomJob(QObject *parent)
     : RestApiAbstractJob(parent)
 {
@@ -28,7 +28,7 @@ bool LoadEmojiCustomJob::start()
         return false;
     }
     submitGetRequest();
-    addStartRestApiInfo(QByteArrayLiteral("LoadEmojiCustomJob: Load Emoji custom"));
+    addStartRestApiInfo("LoadEmojiCustomJob: Load Emoji custom"_ba);
 
     return true;
 }
@@ -38,11 +38,11 @@ void LoadEmojiCustomJob::onGetRequestResponse(const QString &replyErrorString, c
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("LoadEmojiCustomJob done: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("LoadEmojiCustomJob done: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT loadEmojiCustomDone(replyObject);
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("LoadEmojiCustomJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("LoadEmojiCustomJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
