@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -30,25 +30,25 @@ bool AppsUiInteractionJob::start()
     return true;
 }
 
+QDebug operator<<(QDebug d, const RocketChatRestApi::AppsUiInteractionJob::AppsUiInteractionJobInfo &t)
+{
+    d << " messageObj: " << t.messageObj;
+    d << " methodName: " << t.methodName;
+    return d;
+}
+
 void AppsUiInteractionJob::onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson)
 {
-    Q_UNUSED(replyErrorString)
-    Q_UNUSED(replyJson)
-    // qDebug() << " response " << replyErrorString << "replyJson  " << replyJson;
-    // It doesn't return success or not!
-    Q_EMIT appsUiInteractionDone();
-#if 0
     // qDebug() << " response " << replyErrorString << "replyJson  " << replyJson;
     const QJsonObject replyObject = replyJson.object();
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("AppsUiInteractionJob success: ") + replyJson.toJson(QJsonDocument::Indented));
-        const QJsonObject obj = QJsonDocument::fromJson(replyObject["message"_L1].toString().toUtf8()).object();
-        Q_EMIT AppsUiInteractionDone(obj);
+        addLoggerInfo("AppsUiInteractionJob success: "_ba + replyJson.toJson(QJsonDocument::Indented));
+        Q_EMIT appsUiInteractionDone(replyObject);
     } else {
-        emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("AppsUiInteractionJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        Q_EMIT appsUiInteractionFailed(replyObject);
+        // emitFailedMessage(replyErrorString, replyObject);
+        addLoggerWarning("AppsUiInteractionJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
-#endif
 }
 
 AppsUiInteractionJob::AppsUiInteractionJobInfo AppsUiInteractionJob::methodCallJobInfo() const
