@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -381,6 +381,17 @@ QString RestApiUtil::restUrl(RestApiUtil::RestApiUrlType type)
     case RestApiUtil::RestApiUrlType::E2EResetOwnE2EKey:
         return QStringLiteral("e2e.resetOwnE2EKey");
 
+    case RestApiUtil::RestApiUrlType::E2EAcceptSuggestedGroupKey:
+        return QStringLiteral("e2e.acceptSuggestedGroupKey");
+    case RestApiUtil::RestApiUrlType::E2ERejectSuggestedGroupKey:
+        return QStringLiteral("e2e.rejectSuggestedGroupKey");
+    case RestApiUtil::RestApiUrlType::E2EProvideUsersWithSuggestedGroupKeys:
+        return QStringLiteral("e2e.provideUsersWithSuggestedGroupKeys");
+    case RestApiUtil::RestApiUrlType::E2EResetRoomKey:
+        return QStringLiteral("e2e.resetRoomKey");
+    case RestApiUtil::RestApiUrlType::E2EFetchUsersWaitingForGroupKey:
+        return QStringLiteral("e2e.provideUsersSuggestedGroupKeys");
+
     case RestApiUtil::RestApiUrlType::RolesList:
         return QStringLiteral("roles.list");
     case RestApiUtil::RestApiUrlType::RolesCreate:
@@ -512,8 +523,6 @@ QString RestApiUtil::restUrl(RestApiUtil::RestApiUrlType type)
     case RestApiUtil::RestApiUrlType::SettingsAddCustomOauth:
         return QStringLiteral("settings.addCustomOAuth");
 
-    case RestApiUtil::RestApiUrlType::LicensesGet:
-        return QStringLiteral("licenses.get");
     case RestApiUtil::RestApiUrlType::LicensesMaxActiveUsers:
         return QStringLiteral("licenses.maxActiveUsers");
     case RestApiUtil::RestApiUrlType::LicensesAdd:
@@ -618,6 +627,10 @@ QString RestApiUtil::restUrl(RestApiUtil::RestApiUrlType type)
         return QStringLiteral("users.sendWelcomeEmail");
     case RestApiUtil::RestApiUrlType::Empty:
         return {};
+    case RestApiUtil::RestApiUrlType::RoomsImages:
+        return QStringLiteral("rooms.images");
+    case RestApiUtil::RestApiUrlType::RoomsMembersOrderedByRole:
+        return QStringLiteral("rooms.membersOrderedByRole");
     }
     qCWarning(ROCKETCHATQTRESTAPI_LOG) << "Unknown RestApiUtil::RestApiUrlType " << static_cast<int>(type);
     return {};
