@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sessionslistjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
@@ -13,6 +12,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QJsonObject>
 #include <QUrlQuery>
 using namespace RocketChatRestApi;
+using namespace Qt::Literals::StringLiterals;
 SessionsListJob::SessionsListJob(QObject *parent)
     : RestApiAbstractJob(parent)
 {
@@ -28,7 +28,7 @@ bool SessionsListJob::start()
         return false;
     }
     submitGetRequest();
-    addStartRestApiInfo(QByteArrayLiteral("SessionsListJob: Ask custom sounds info"));
+    addStartRestApiInfo("SessionsListJob: Ask custom sounds info"_ba);
 
     return true;
 }
@@ -38,11 +38,11 @@ void SessionsListJob::onGetRequestResponse(const QString &replyErrorString, cons
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("SessionsListJob done: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("SessionsListJob done: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT sessionsListDone(replyObject);
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("SessionsListJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("SessionsListJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
