@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "getpresencejob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
 #include <QJsonDocument>
 #include <QJsonObject>
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 GetPresenceJob::GetPresenceJob(QObject *parent)
     : UserBaseJob(parent)
@@ -47,11 +47,11 @@ void GetPresenceJob::onGetRequestResponse(const QString &replyErrorString, const
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("GetPresenceJob: success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("GetPresenceJob: success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT getPresenceDone(replyObject["presence"_L1].toString());
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("GetPresenceJob problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("GetPresenceJob problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
