@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "resetavatarjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
@@ -13,6 +12,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QJsonDocument>
 #include <QJsonObject>
 using namespace RocketChatRestApi;
+using namespace Qt::Literals::StringLiterals;
 ResetAvatarJob::ResetAvatarJob(QObject *parent)
     : UserBaseJob(parent)
 {
@@ -35,11 +35,11 @@ void ResetAvatarJob::onPostRequestResponse(const QString &replyErrorString, cons
 {
     const QJsonObject replyObject = replyJson.object();
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("ResetAvatarJob: success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("ResetAvatarJob: success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT resetAvatarDone();
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("ResetAvatarJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("ResetAvatarJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
