@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,6 +7,7 @@
 #pragma once
 
 #include "libruqolawidgets_export.h"
+#include "model/listmessagesfilterproxymodel.h"
 #include <QDialog>
 
 class ShowListMessageBaseWidget;
@@ -20,12 +21,14 @@ public:
     explicit ShowListMessageBaseDialog(RocketChatAccount *account, QWidget *parent = nullptr);
     ~ShowListMessageBaseDialog() override;
 
-    void setModel(ListMessagesFilterProxyModel *model);
-
+    void setFilterProxyModel(ListMessagesFilterProxyModel *model);
+    void setFilteringByType(ListMessagesFilterProxyModel::FilteringByType type);
     void setRoomId(const QByteArray &roomId);
     [[nodiscard]] QByteArray roomId() const;
     void setRoom(Room *room);
 
+    void addMessageLineWidget(QWidget *w);
+
 Q_SIGNALS:
     void goToMessageRequested(const QByteArray &messageId, const QString &messageDateTimeUtc);
 
