@@ -86,14 +86,16 @@ protected:
     void drawTitle(const MessageAttachment &msgAttach, QPainter *painter);
     [[nodiscard]] MessageDelegateHelperBase::DocumentDescriptionInfo convertAttachmentToDocumentTitleInfo(const MessageAttachment &msgAttach, int width) const;
 
-private:
-    enum class DocumentIdType : int {
+protected:
+    enum class DocumentIdType : uint8_t {
         Unknown = 0,
         Title,
         Description,
     };
-    [[nodiscard]] LIBRUQOLAWIDGETS_NO_EXPORT QByteArray documentId(MessageAttachmentDelegateHelperBase::DocumentIdType type,
-                                                                   const MessageAttachment &msgAttach) const;
+    Q_ENUM(DocumentIdType);
+    [[nodiscard]] QByteArray documentId(MessageAttachmentDelegateHelperBase::DocumentIdType type, const MessageAttachment &msgAttach) const;
+
+private:
     [[nodiscard]] LIBRUQOLAWIDGETS_NO_EXPORT QByteArray documendIdPrefix(MessageAttachmentDelegateHelperBase::DocumentIdType type) const;
     [[nodiscard]] LIBRUQOLAWIDGETS_NO_EXPORT MessageDelegateHelperBase::DocumentDescriptionInfo
     convertAttachmentToDocumentTypeInfo(DocumentIdType type, const MessageAttachment &msgAttach, int width) const;
