@@ -1,6 +1,6 @@
 /*
    SPDX-FileCopyrightText: 2020 David Faure <faure@kde.org>
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -26,6 +26,8 @@
 #include "misc/emoticonmenuwidget.h"
 #include "model/messagesmodel.h"
 #include "rocketchataccount.h"
+#include "room/delegate/messagedelegatehelpercontext.h"
+#include "room/delegate/messagedelegatehelperdivider.h"
 #include "room/delegate/messagelistlayout/messagelistcompactlayout.h"
 #include "room/delegate/messagelistlayout/messagelistcozylayout.h"
 #include "room/delegate/messagelistlayout/messagelistnormallayout.h"
@@ -48,6 +50,8 @@
 #include <KLocalizedString>
 #include <QMenu>
 
+// #define DEBUG_PAINTING
+
 MessageListDelegate::MessageListDelegate(RocketChatAccount *account, QListView *view)
     : QItemDelegate(view)
     , mEditedIcon(QIcon::fromTheme(QStringLiteral("document-edit")))
@@ -56,7 +60,7 @@ MessageListDelegate::MessageListDelegate(RocketChatAccount *account, QListView *
     , mFavoriteIcon(QIcon::fromTheme(QStringLiteral("favorite")))
     , mFollowingIcon(QIcon::fromTheme(QStringLiteral("notifications")))
     , mPinIcon(QIcon::fromTheme(QStringLiteral("pin")))
-    , mTranslatedIcon(QIcon::fromTheme(QStringLiteral("languages"))) // TODO use another icon for it. But kde doesn't correct icon perhaps flags ?
+    , mTranslatedIcon(QIcon::fromTheme(QStringLiteral("translate")))
     , mReplyInThreadIcon(QIcon::fromTheme(QStringLiteral("view-conversation-balloon-symbolic")))
     , mListView(view)
     , mTextSelectionImpl(new TextSelectionImpl)
@@ -71,6 +75,8 @@ MessageListDelegate::MessageListDelegate(RocketChatAccount *account, QListView *
     , mHelperActions(new MessageDelegateHelperActions(account, view, mTextSelectionImpl))
     , mHelperSection(new MessageDelegateHelperSection(account, view, mTextSelectionImpl))
     , mHelperUrlPreview(new MessageDelegateHelperUrlPreview(account, view, mTextSelectionImpl))
+    , mHelperDivider(new MessageDelegateHelperDivider(account, view, mTextSelectionImpl))
+    , mHelperContext(new MessageDelegateHelperContext(account, view, mTextSelectionImpl))
     , mAvatarCacheManager(new AvatarCacheManager(Utils::AvatarType::User, this))
     , mMessageListLayoutBase(new MessageListCompactLayout(this))
 {
@@ -136,6 +142,8 @@ void MessageListDelegate::setRocketChatAccount(RocketChatAccount *rcAccount)
     mHelperActions->setRocketChatAccount(mRocketChatAccount);
     mHelperSection->setRocketChatAccount(mRocketChatAccount);
     mHelperUrlPreview->setRocketChatAccount(mRocketChatAccount);
+    mHelperDivider->setRocketChatAccount(mRocketChatAccount);
+    mHelperContext->setRocketChatAccount(mRocketChatAccount);
 }
 
 QPixmap MessageListDelegate::makeAvatarPixmap(const QWidget *widget, const QModelIndex &index, int maxHeight) const
@@ -167,6 +175,16 @@ MessageBlockDelegateHelperBase *MessageListDelegate::blocksHelper(const Block &b
         return mHelperActions.get();
     case Block::BlockType::Section:
         return mHelperSection.get();
+    case Block::BlockType::Context:
+        return mHelperContext.get();
+    case Block::BlockType::Divider:
+        return mHelperDivider.get();
+    case Block::BlockType::Overflow: // TODO look at it!
+    case Block::BlockType::Image: // TODO look at it!
+    case Block::BlockType::Preview: // TODO look at it!
+    case Block::BlockType::Callout: // TODO look at it!
+        qCWarning(RUQOLAWIDGETS_LOG) << " not implemented BlockType " << block.blockType();
+        return nullptr;
     }
     return nullptr;
 }
@@ -537,7 +555,7 @@ void MessageListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
 
     // Message
     if (layout.textRect.isValid()) {
-#if 0
+#ifdef DEBUG_PAINTING
         painter->save();
         painter->setPen(QPen(Qt::red));
         painter->drawRect(layout.textRect);
@@ -562,7 +580,7 @@ void MessageListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
         painter->drawText(layout.senderRect.x(), layout.baseLine, layout.senderText);
         painter->setFont(oldFont);
 
-#if 0
+#ifdef DEBUG_PAINTING
         painter->save();
         painter->setPen(QPen(Qt::red));
         painter->drawRect(layout.senderRect);
@@ -592,7 +610,7 @@ void MessageListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
         mFollowingIcon.paint(painter, layout.followingIconRect);
     }
     // Draw translated string
-    if (message->isAutoTranslated()) {
+    if (message->isAutoTranslated() || !message->localTranslation().isEmpty()) {
         mTranslatedIcon.paint(painter, layout.translatedIconRect);
     }
 
@@ -608,7 +626,7 @@ void MessageListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
         for (const MessageAttachment &att : attachments) {
             const MessageAttachmentDelegateHelperBase *helper = attachmentsHelper(att);
             if (helper) {
-#if 0
+#ifdef DEBUG_PAINTING
                 painter->save();
                 painter->setPen(QPen(Qt::green));
                 painter->drawRect(layout.attachmentsRectList.at(i));
@@ -627,7 +645,7 @@ void MessageListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
         for (const Block &block : blocks) {
             const MessageBlockDelegateHelperBase *helper = blocksHelper(block);
             if (helper) {
-#if 0
+#ifdef DEBUG_PAINTING
                 painter->save();
                 painter->setPen(QPen(Qt::red));
                 painter->drawRect(layout.blocksRectList.at(blockIndex));
@@ -960,7 +978,7 @@ bool MessageListDelegate::helpEvent(QHelpEvent *helpEvent, QAbstractItemView *vi
         if (layout.senderRect.contains(helpEventPos)) {
             QString tooltip = message->name();
 
-            if (mRocketChatAccount && mRocketChatAccount->useRealName() && !tooltip.isEmpty()) {
+            if (mRocketChatAccount && mRocketChatAccount->ruqolaServerConfig()->useRealName() && !tooltip.isEmpty()) {
                 tooltip = QLatin1Char('@') + message->username();
             }
 
@@ -999,7 +1017,7 @@ bool MessageListDelegate::helpEvent(QHelpEvent *helpEvent, QAbstractItemView *vi
             QToolTip::showText(helpEvent->globalPos(), i18nc("@info:tooltip", "Add reaction"), view);
             return true;
         }
-        if (layout.textRect.contains(helpEvent->pos()) && mHelperText->handleHelpEvent(helpEvent, layout.textRect, index)) {
+        if (layout.textRect.contains(helpEventPos) && mHelperText->handleHelpEvent(helpEvent, layout.textRect, index)) {
             return true;
         }
         // Attachments
@@ -1048,7 +1066,7 @@ bool MessageListDelegate::helpEvent(QHelpEvent *helpEvent, QAbstractItemView *vi
                 }
             }
         }
-        if (layout.timeStampRect.contains(helpEvent->pos())) {
+        if (layout.timeStampRect.contains(helpEventPos)) {
             const QString dateStr = index.data(MessagesModel::Date).toString();
             QToolTip::showText(helpEvent->globalPos(), dateStr, view);
             return true;
@@ -1059,7 +1077,7 @@ bool MessageListDelegate::helpEvent(QHelpEvent *helpEvent, QAbstractItemView *vi
 
 void MessageListDelegate::slotPrivateSettingsChanged()
 {
-    mPreviewEmbed = mRocketChatAccount ? mRocketChatAccount->previewEmbed() : true;
+    mPreviewEmbed = mRocketChatAccount ? mRocketChatAccount->ruqolaServerConfig()->previewEmbed() : true;
 }
 
 void MessageListDelegate::clearAvatarSizeHintCache()
@@ -1088,7 +1106,7 @@ void MessageListDelegate::switchMessageLayout()
         break;
     }
     mMessageListLayoutBase->setRocketChatAccount(mRocketChatAccount);
-    mPreviewEmbed = mRocketChatAccount ? mRocketChatAccount->previewEmbed() : true;
+    mPreviewEmbed = mRocketChatAccount ? mRocketChatAccount->ruqolaServerConfig()->previewEmbed() : true;
     Q_EMIT updateView();
 }
 
