@@ -1,11 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
 
+#include "commands/previewscommandjob.h"
+#include "commands/runcommandjob.h"
 #include "dialogs/uploadfiledialog.h"
 #include "libruqolawidgets_private_export.h"
 #include "uploadfilejob.h"
@@ -17,6 +19,7 @@ class EmoticonMenuWidget;
 class RocketChatAccount;
 class QMimeData;
 class MessagesModel;
+class PluginToolInterface;
 
 class LIBRUQOLAWIDGETS_TESTS_EXPORT MessageLineWidget : public QWidget
 {
@@ -64,11 +67,14 @@ public:
     [[nodiscard]] QString quoteText() const;
 
     void setRoomName(const QString &roomName, bool thread = false);
+
+    void setSendPreviewCommandInfo(const RocketChatRestApi::PreviewsCommandJob::PreviewsCommandInfo &info);
 Q_SIGNALS:
     void keyPressed(QKeyEvent *ev);
     void threadMessageIdChanged(const QByteArray &threadMessageId, const QString &text);
     void quoteMessageChanged(const QString &permalink, const QString &text);
     void createUploadJob(const RocketChatRestApi::UploadFileJob::UploadFileInfo &info);
+    void showCommandPreview(const RocketChatRestApi::PreviewsCommandJob::PreviewsCommandInfo &info);
 
 private:
     LIBRUQOLAWIDGETS_NO_EXPORT void slotSendMessage(const QString &msg);
@@ -82,7 +88,11 @@ private:
     LIBRUQOLAWIDGETS_NO_EXPORT void slotSendVideoMessage();
     LIBRUQOLAWIDGETS_NO_EXPORT void slotSendSoundMessage();
     LIBRUQOLAWIDGETS_NO_EXPORT void slotPrivateSettingsChanged();
+    [[nodiscard]] LIBRUQOLAWIDGETS_NO_EXPORT bool runCommand(const QString &msg, const QByteArray &roomId, const QByteArray &tmid);
+    LIBRUQOLAWIDGETS_NO_EXPORT void slotRunCommandFailed(const RocketChatRestApi::RunCommandJob::RunCommandInfo &info);
+    [[nodiscard]] LIBRUQOLAWIDGETS_NO_EXPORT bool hasCommandPreview(const QString &msg, const QByteArray &roomId);
 
+    QList<PluginToolInterface *> mPluginToolInterface;
     QByteArray mThreadMessageId;
     QByteArray mMessageIdBeingEdited;
     QString mQuotePermalink;
