@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -29,7 +29,6 @@ QString AccountInfoSource::description() const
 
 QVariant AccountInfoSource::data()
 {
-    QVariantMap m;
-    m.insert(QStringLiteral("value"), Ruqola::self()->accountManager()->accountNumber());
+    const QVariantMap m{{QStringLiteral("value"), Ruqola::self()->accountManager()->accountNumber()}};
     return m;
 }
